(TeX-add-style-hook "vars"
 (function
  (lambda ()
    (LaTeX-add-bibliographies
     "vars")
    (LaTeX-add-labels
     "sec:intro"
     "sec:var"
     "subsec:var-def"
     "eq1"
     "subsec:var-est"
     "fig-canada"
     "fig-e"
     "fig-prod"
     "fig-rw"
     "fig-U"
     "subsec:var-res"
     "subsec:var-diag"
     "1st"
     "2nd"
     "fig-stab.e"
     "fig-stab.prod"
     "fig-stab.rw"
     "fig-stab.U"
     "subsec:var-cause"
     "subsec:var-pred"
     "eq15"
     "eq16"
     "fig-e.prd"
     "fig-U.prd"
     "subsec:var-ira"
     "fig-irf"
     "subsec:var-fevd"
     "fig-fevd"
     "sec:svar"
     "subsec:svar-def"
     "eq21"
     "eq22"
     "subsec:svar-est"
     "eq23"
     "eq24"
     "eq25"
     "eq26"
     "eq27"
     "subsec:svar-ira"
     "subsec:svar-fevd"
     "fig-svarfevd"
     "sec:vec2var"
     "eq28"
     "eq29"
     "eq30"
     "eq31"
     "eq32"
     "eq33")
    (TeX-run-style-hooks
     "amsmath"
     "harvard"
     "latex2e"
     "art10"
     "article"
     "a4paper"))))

